/*
 * © 2009 David ‘Bombe’ Roden
 */
package net.pterodactylus.arachne.core;

/**
 * Container for a page. A page consists of a {@link Site} and a path within the
 * site.
 *
 * @author David ‘Bombe’ Roden <bombe@pterodactylus.net>
 */
public class Page {

	/** The site of the page. */
	private final Site site;

	/** The path of the page. */
	private final String path;

	/**
	 * Creates a new page.
	 *
	 * @param site
	 *            The site of the page
	 * @param path
	 *            The path of the page
	 */
	public Page(Site site, String path) {
		this.site = site;
		this.path = path;
	}

	/**
	 * Returns the site of the page.
	 *
	 * @return The page’s site
	 */
	public Site getSite() {
		return site;
	}

	/**
	 * Returns the path of the page within the site.
	 *
	 * @return The page’s path
	 */
	public String getPath() {
		return path;
	}

}
